@@ -58,6 +58,16 @@ def open_accounts(app):
 def get_sibling_offset(node, offset):
     return node.parent.children[node.indexInParent+offset]
 
+def get_sibling_button_maybe(button):
+    try:
+        # if there is a sibling button (without the name) that's the one that works
+        button_sibling = button.parent.children[button.indexInParent + 1]
+        if button_sibling.roleName == "push button":
+            return button_sibling
+    except KeyError:
+        pass
+    return button
+
 def add_local_account(app):
     accounts_tab = None
     settings = None
@@ -138,7 +148,9 @@ def attach(app, compose_window, path):
     file_chooser.button('Attach').doActionNamed('click')
 
 def send_email(app, sign=False, encrypt=False, inline=False, attachment=None):
-    app.button('New').doActionNamed('click')
+    new_button = app.button('New')
+    new_button = get_sibling_button_maybe(new_button)
+    new_button.doActionNamed('click')
     new_message = app.child('Compose Message', roleName='frame')
     new_message.textentry('To:').text = 'user@localhost,'
     new_message.childLabelled('Subject:').text = subject
@@ -160,7 +172,9 @@ def send_email(app, sign=False, encrypt=False, inline=False, attachment=None):
     new_message.button('Send').doActionNamed('click')
 
 def receive_message(app, signed=False, encrypted=False, attachment=None):
-    app.button('Send / Receive').doActionNamed('click')
+    send_receive = app.button('Send / Receive')
+    send_receive = get_sibling_button_maybe(send_receive)
+    send_receive.doActionNamed('click')
     app.child(name='Inbox.*', roleName='table cell').doActionNamed('edit')
     messages = app.child('Messages', roleName='panel')
     messages.child(subject).grabFocus()
